
# test.contrib

This folder contains files adopted from other (license-compatible) sources.
In particular, code is repurposed from Antmicro's usb-test-suite.

See individual files for their licenses.
